@@ -32,6 +32,9 @@
 #include <gdata/gdata-parsable.h>
 #include <gdata/gdata-download-stream.h>
 #include <gdata/gdata-upload-stream.h>
+#include <gdata/gdata-comparable.h>
+#include <gdata/gdata-batchable.h>
+#include <gdata/gdata-batch-operation.h>
 
 /* Namespaces */
 
@@ -41,6 +44,9 @@
 #include <gdata/atom/gdata-generator.h>
 #include <gdata/atom/gdata-link.h>
 
+/* APP */
+#include <gdata/app/gdata-app-categories.h>
+
 /* GData */
 #include <gdata/gd/gdata-gd-email-address.h>
 #include <gdata/gd/gdata-gd-im-address.h>
@@ -53,6 +59,15 @@
 #include <gdata/gd/gdata-gd-where.h>
 #include <gdata/gd/gdata-gd-who.h>
 
+/* GContact */
+#include <gdata/gcontact/gdata-gcontact-calendar.h>
+#include <gdata/gcontact/gdata-gcontact-event.h>
+#include <gdata/gcontact/gdata-gcontact-external-id.h>
+#include <gdata/gcontact/gdata-gcontact-jot.h>
+#include <gdata/gcontact/gdata-gcontact-language.h>
+#include <gdata/gcontact/gdata-gcontact-relation.h>
+#include <gdata/gcontact/gdata-gcontact-website.h>
+
 /* Media RSS */
 #include <gdata/media/gdata-media-category.h>
 #include <gdata/media/gdata-media-content.h>
@@ -70,6 +85,7 @@
 #include <gdata/services/youtube/gdata-youtube-credit.h>
 #include <gdata/services/youtube/gdata-youtube-state.h>
 #include <gdata/services/youtube/gdata-youtube-enums.h>
+#include <gdata/services/youtube/gdata-youtube-category.h>
 
 /* Google Calendar */
 #include <gdata/services/calendar/gdata-calendar-service.h>
@@ -80,18 +96,22 @@
 
 /* Google PicasaWeb */
 #include <gdata/services/picasaweb/gdata-picasaweb-service.h>
+#include <gdata/services/picasaweb/gdata-picasaweb-feed.h>
 #include <gdata/services/picasaweb/gdata-picasaweb-query.h>
 #include <gdata/services/picasaweb/gdata-picasaweb-album.h>
 #include <gdata/services/picasaweb/gdata-picasaweb-file.h>
 #include <gdata/services/picasaweb/gdata-picasaweb-enums.h>
+#include <gdata/services/picasaweb/gdata-picasaweb-user.h>
 
 /* Google Contacts */
 #include <gdata/services/contacts/gdata-contacts-service.h>
 #include <gdata/services/contacts/gdata-contacts-contact.h>
+#include <gdata/services/contacts/gdata-contacts-group.h>
 #include <gdata/services/contacts/gdata-contacts-query.h>
 
 /* Google Documents*/
 #include <gdata/services/documents/gdata-documents-entry.h>
+#include <gdata/services/documents/gdata-documents-document.h>
 #include <gdata/services/documents/gdata-documents-text.h>
 #include <gdata/services/documents/gdata-documents-spreadsheet.h>
 #include <gdata/services/documents/gdata-documents-presentation.h>
@@ -99,5 +119,6 @@
 #include <gdata/services/documents/gdata-documents-query.h>
 #include <gdata/services/documents/gdata-documents-service.h>
 #include <gdata/services/documents/gdata-documents-feed.h>
+#include <gdata/services/documents/gdata-documents-enums.h>
 
 #endif /* !GDATA_H */
