@@ -36,6 +36,7 @@
 #include <glib.h>
 
 #include "gdata-documents-text.h"
+#include "gdata-parser.h"
 
 static void get_xml (GDataParsable *parsable, GString *xml_string);
 
@@ -67,7 +68,7 @@ get_xml (GDataParsable *parsable, GString *xml_string)
 
 	document_id = gdata_documents_entry_get_document_id (GDATA_DOCUMENTS_ENTRY (parsable));
 	if (document_id != NULL)
-		g_string_append_printf (xml_string, "<gd:resourceId>document:%s</gd:resourceId>", document_id);
+		gdata_parser_string_append_escaped (xml_string, "<gd:resourceId>document:", document_id, "</gd:resourceId>");
 }
 
 /**
